==> haskell-openssl-streams-1.2.3.0-284-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-7yn3uW8KnJEIEaj912oqKr
key:                  openssl-streams-1.2.3.0-7yn3uW8KnJEIEaj912oqKr
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  f18cd44aba994f38d8f56b88ca2048b5
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-7yn3uW8KnJEIEaj912oqKr
depends:
    HsOpenSSL-0.11.7.9-7rM3XcO073UGlPooPcpWFC base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-K5IjzkNNmAf7LdMcsmPYbB
    network-3.1.4.0-9ZkyLgutzTZFWrHs4BgIgX

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.3.0-285-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-cIFXl0hoSYLdwrIerMtLZ
key:                  openssl-streams-1.2.3.0-cIFXl0hoSYLdwrIerMtLZ
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  220e6adf0910391c5533dda2647af26a
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-cIFXl0hoSYLdwrIerMtLZ
depends:
    HsOpenSSL-0.11.7.9-Iw1EFh3wZS8LcoBYdzqrEa base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-Lc9jp7HstmCBhGo4hU2E1L
    network-3.1.4.0-Aot7Hsnd3no7HIoU7vrrpP

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
